Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3447)

Unified Diff: chrome/browser/ui/cocoa/hung_renderer_controller.mm

Issue 10703061: chrome/browser/ui: Put browser_dialogs.h into chrome namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/hung_renderer_controller.mm
diff --git a/chrome/browser/ui/cocoa/hung_renderer_controller.mm b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
index 0f2b8eb907ea3d3f76448c7dfebcf77395e3555d..43a8b7af446046eeb7eba1a644113493320e7ec3 100644
--- a/chrome/browser/ui/cocoa/hung_renderer_controller.mm
+++ b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
@@ -15,8 +15,8 @@
#import "chrome/browser/ui/cocoa/multi_key_equivalent_button.h"
#import "chrome/browser/ui/cocoa/tab_contents/favicon_util.h"
#include "chrome/browser/ui/tab_contents/core_tab_helper.h"
-#include "chrome/browser/ui/tab_contents/tab_contents_iterator.h"
#include "chrome/browser/ui/tab_contents/tab_contents.h"
+#include "chrome/browser/ui/tab_contents/tab_contents_iterator.h"
#include "chrome/common/logging_chrome.h"
#include "content/public/browser/render_process_host.h"
#include "content/public/browser/render_view_host.h"
@@ -154,8 +154,8 @@ class WebContentsObserverBridge : public content::WebContentsObserver {
- (void)windowWillClose:(NSNotification*)notification {
// We have to reset g_instance before autoreleasing the window,
// because we want to avoid reusing the same dialog if someone calls
// browser::ShowHungRendererDialog() between the autorelease
// call and the actual dealloc.
g_instance = nil;
[self autorelease];
@@ -217,7 +217,7 @@ class WebContentsObserverBridge : public content::WebContentsObserver {
}
@end
-namespace browser {
+namespace chrome {
void ShowHungRendererDialog(WebContents* contents) {
if (!logging::DialogsAreSuppressed()) {
@@ -233,4 +233,4 @@ void HideHungRendererDialog(WebContents* contents) {
[g_instance endForWebContents:contents];
}
-} // namespace browser
+} // namespace chrome

Powered by Google App Engine
This is Rietveld 408576698
@@ -154,8 +154,8 @@ class WebContentsObserverBridge : public content::WebContentsObserver {
// We have to reset g_instance before autoreleasing the window,
// because we want to avoid reusing the same dialog if someone calls
- // browser::ShowHungRendererDialog() between the autorelease
- // call and the actual dealloc.
+ // chrome::ShowHungRendererDialog() between the autorelease call and the
+ // actual dealloc.
g_instance = nil;
[self autorelease];